@@ -8,12 +8,17 @@ module Bogus
       stubbing_non_existent_method!(object, method_name) unless object.respond_to?(method_name)
       return unless object.methods.include?(method_name)
       return if WithArguments.with_matcher?(args)
-      method = object.method(method_name)
+      method = get_method_object(object, method_name)
       verify_call!(method, args)
     end
 
     private
 
+    def get_method_object(object, method_name)
+      return object.instance_method(:initialize) if constructor?(object, method_name)
+      object.method(method_name)
+    end
+
     def verify_call!(method, args)
       object = Object.new
       fake_method = method_stringifier.stringify(method, "")
@@ -31,5 +36,9 @@ module Bogus
     def stubbing_non_existent_method!(object, method_name)
       raise NameError, "#{object.inspect} does not respond to #{method_name}"
     end
+
+    def constructor?(object, method_name)
+      method_name.to_sym == :new && object.kind_of?(Class)
+    end
   end
 end
