@@ -9,16 +9,16 @@ describe Bogus::AddsRecording do
     end
   end
 
-  let(:create_proxy_class) { stub }
-  let(:overwrites_classes) { stub }
-  let(:overwritten_classes) { stub }
+  let(:create_proxy_class) { double }
+  let(:overwrites_classes) { double }
+  let(:overwritten_classes) { double }
 
   let(:adds_recording) { isolate(Bogus::AddsRecording) }
 
   before do
-    stub(create_proxy_class).call { Object }
-    stub(overwrites_classes).overwrite
-    stub(overwritten_classes).add
+    allow(create_proxy_class).to receive(:call) { Object }
+    allow(overwrites_classes).to receive(:overwrite)
+    allow(overwritten_classes).to receive(:add)
   end
 
   before do
@@ -26,15 +26,15 @@ describe Bogus::AddsRecording do
   end
 
   it "creates the proxy" do
-    expect(create_proxy_class).to have_received.call(:library, SampleModule::Library)
+    expect(create_proxy_class).to have_received(:call).with(:library, SampleModule::Library)
   end
 
   it "swaps the classes" do
-    expect(overwrites_classes).to have_received.overwrite('SampleModule::Library', Object)
+    expect(overwrites_classes).to have_received(:overwrite).with('SampleModule::Library', Object)
   end
 
   it "records the overwritten class, so that it can be later restored" do
-    expect(overwritten_classes).to have_received.add("SampleModule::Library", SampleModule::Library)
+    expect(overwritten_classes).to have_received(:add).with("SampleModule::Library", SampleModule::Library)
   end
 
   it "returns the proxy class" do
