@@ -1,15 +1,15 @@
 require 'spec_helper'
 
 describe Bogus::ResetsStubbedMethods do
-  let(:double_tracker) { stub }
-  let(:overwrites_methods) { stub }
+  let(:double_tracker) { double }
+  let(:overwrites_methods) { double }
 
   let(:resets_stubbed_methods) { isolate(Bogus::ResetsStubbedMethods) }
 
   it "resets all stubbed objects back to previous implementation" do
-    foo = stub
-    stub(double_tracker).doubles { [foo] }
-    mock(overwrites_methods).reset(foo)
+    foo = double
+    allow(double_tracker).to receive(:doubles) { [foo] }
+    expect(overwrites_methods).to receive(:reset).with(foo)
 
     resets_stubbed_methods.reset_all_doubles
   end
